<?php
/**
 *
 * Lets Info Up Block
 *
 * @since      1.1.0
 *
 * @package    Lets Info Up
 * @subpackage lets-info-up/admin
 */

class Lets_Info_Up_Block {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	*/
	public function __construct( $slug = '', $version = '', $url = '' ) {
		$this->slug = $slug;
		$this->version = $version;
		$this->url = $url;
	}

	/**
	 * Enqueue assets
	 *
	 * @since 1.0.0
	 */
	function lets_info_up_block_assets() {
		wp_enqueue_style(
			'lets-info-up-style-css',
			esc_url( $this->url . 'admin/block/dist/blocks.style.build.css' ),
			array(),
			$this->version
		);
	}

	/**
	 * Enqueue assets
	 *
	 * @since 1.0.0
	 */
	function lets_info_up_editor_assets() {

		wp_enqueue_script(
			'lets-info-up-block-js',
			esc_url( $this->url . 'admin/block/dist/blocks.build.js' ),
			array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor', 'wp-compose' ),
			$this->version,
			true
		);
		$args = array();

		$args['dateFormat'] = get_option( 'date_format' );
		wp_localize_script( 'lets-info-up-block-js', 'letsInfoUpBlockJS',
			array(
				'args'                => $args,
			)
		);

		wp_enqueue_style(
			'lets-info-up-block-editor-css',
			esc_url( $this->url . 'admin/block/dist/blocks.editor.build.css' ),
			array( 'wp-edit-blocks' ),
			$this->version
		);
		$rtl = is_rtl() ? '-rtl' : '';
		wp_enqueue_style(
			'lets-info-up-editor-css',
			esc_url( $this->url . 'frontend/css/style.min' . $rtl . '.css' ),
			array( 'wp-edit-blocks' ),
			$this->version
		);
	}

	function lets_info_up_block_category( $categories, $post ) {
		return array_merge(
			$categories,
			array(
				array(
					'slug' => 'lets-info-up-blocks',
					'title' => __( "Let's Info Up", 'lets-info-up-blocks' ),
				),
			)
		);
	}

	function lets_info_up_callback( $attr = '' ) {
		$output = new Lets_Info_Up_Frontend();
		return $output->block_output( $attr );
	}

	function lets_info_up_block_callbacks() {
		if ( function_exists( 'register_block_type' ) ) {
			register_block_type(
				'lets-info-up/block-info', array(
					'render_callback' => array( $this, 'lets_info_up_callback' ),
				)
			);
		}
	}

}
