<?php

/**
 *
 * Let's Review API Class
 *
 * @since      1.1.0
 *
 * @package    Let's Review
 * @subpackage lets-review/admin
 */

class Lets_Review_API {

	/**
	 * Get review final score
	 *
	 * @since    1.1.0
	 */
	public function lets_review_get_final_score( $lets_review_post_id = '' ) {

		if ( get_post_meta( $lets_review_post_id, '_lets_review_onoff', true ) != 1 ) {
			return;
		} else {
			$lets_review_frontend = new Lets_Review_Frontend( '', '', '' );
			$lets_review_format = get_post_meta( $lets_review_post_id, '_lets_review_format', true );
			$lets_review_ext =  $lets_review_format == 1 ? '<span class="cb-percent-sign">%</span>' : '';
			return $lets_review_frontend->lets_review_final_score( $lets_review_post_id, true ) . $lets_review_ext;
		}

	}

	/**
	 * Get review final score subtitle
	 *
	 * @since    1.1.0
	 */
	public function lets_review_get_final_score_subtitle( $lets_review_post_id = '' ) {

		if ( get_post_meta( $lets_review_post_id, '_lets_review_onoff', true ) != 1 ) {
			return;
		} else {
			return get_post_meta( $lets_review_post_id, '_lets_review_subtitle', true );
		}

	}

	/**
	 * Get review color
	 *
	 * @since    1.1.0
	 */
	public function lets_review_get_color( $lets_review_post_id = '' ) {

		if ( get_post_meta( $lets_review_post_id, '_lets_review_onoff', true ) != 1 ) {
			return;
		} else {
			$lets_review_frontend = new Lets_Review_Frontend( '', '', '' );
			return $lets_review_frontend->lets_review_color( $lets_review_post_id );
		}

	}

	/**
	 * Check if review is on
	 *
	 * @since    1.1.0
	 */
	public function lets_review_get_onoff( $lets_review_post_id = '' ) {

		if ( substr( $this->lets_review_get_final_score( $lets_review_post_id  ), 0, 1 )  === '-' ) {
			return false;
		}

		if ( get_post_meta( $lets_review_post_id, '_lets_review_onoff', true ) == 1 ) {
			return true;
		} else { 
			return false;
		}
		
	}

	/**
	 * Output helper
	 *
	 * @since    2.0
	 */
	static public function lets_review_get_score_box( $lets_review_post_id = '', $args = array( 'classes' => '', 'color' => '' ) ) {

		if ( get_post_meta( $lets_review_post_id, '_lets_review_onoff', true ) != 1 ) {
			return;
		}
		$lets_review_frontend = new Lets_Review_Frontend( '', '', '' );
		$lets_review_format = get_post_meta( $lets_review_post_id, '_lets_review_format', true );
		$lets_review_ext = 1 == $lets_review_format ? '<span class="cb-percent-sign">%</span>' : '';
		$f_score = $lets_review_frontend->lets_review_final_score( $lets_review_post_id, true );
		$data = $lets_review_frontend->lets_review_final_score( $lets_review_post_id, true, '' , '', true );

		if ( empty( $f_score ) ) {
			return;
		}

		$color = empty( $args['color'] ) ? $lets_review_frontend->lets_review_color( $lets_review_post_id ) : $args['color'];
		$output = '<div class="lets-review-api-wrap cb-font-header cb-lr-font-heading clearfix lr-api-format-' . (int) $data['format'];
		$output .= empty( $args['classes'] ) ? '"' : ' ' . esc_attr( $args['classes'] ) . '"';
		if ( ! empty( $color ) ) {
			$output .= ' style="background-color: ' . $color . ';"';
		}
		$score = $data['score'];
		$score_100 = $score;
		if ( 2 == $data['format'] ) {
			$score_100 = $score * 10;
		} elseif ( 3 == $data['format'] || 4 == $data['format'] || 5 == $data['format'] ) {
			$score_100 = $score * 20;
		}
		$score_100 = $score_100 > 100 ? 100 : $score_100;
		$output .= ' data-api-score="' . floatval( $score ) . '"';
		$output .= ' data-api-100="' . (int) $score_100 . '"';
		$output .= ' data-api-format="' . (int) $data['format'] . '"';
		$output .= '>';
		$output .= '<div class="lets-review-api-score-box">';
		$output .= '<div class="lets-review-final-score">' . $f_score . $lets_review_ext . '</div>';
		$subtitle = get_post_meta( $lets_review_post_id, '_lets_review_subtitle', true );
		if ( ! empty( $subtitle ) ) {
			$output .= '<div class="lets-review-subtitle">' . esc_attr( $subtitle ) . '</div>';
		}
		$output .= '</div></div>';

		return $output;

	}

	/**
	 * Get review final score only
	 *
	 * @since    2.0.3
	 */
	public function lets_review_get_final_score_only( $lets_review_post_id = '' ) {

		if ( get_post_meta( $lets_review_post_id, '_lets_review_onoff', true ) != 1 ) {
			return;
		} else {
			$f_score = get_post_meta( $pid, '_lets_review_final_score', true );
			return $f_score;
		}

	}

}