<?php

/**
 *
 * Let's Review Shortcodes Class
 *
 * @since      2.0.0
 *
 * @package    Let's Review
 * @subpackage lets-review/frontend
 */

class Lets_Review_Shortcodes {

	/**
	 * Var for Let's Review slug.
	 *
	 * @since    1.0.0
	 */
	private $slug;

	/**
	 * Var for Let's Review version.
	 *
	 * @since    1.0.0
	 */
	private $version;

	/**
	 * Var for Let's Review URL.
	 *
	 * @since    1.0.0
	 */
	private $url;

	/**
     * Frontend Constructor
     *
     * @since 1.0.0
     *
    */
	public function __construct( $slug = '', $version = '', $url = '' ) {

		$this->slug = $slug;
		$this->version = $version;
		$this->url = $url;

	}

   	/**
	 * Shortcode output
	 *
	 * @since 1.0.0
	 * @return Review output
	 */
	public function lets_review_shortcode( $atts = array(), $content = '' ) {
		global $post;
		$atts = empty( $atts ) ? array() : $atts;

		if ( ! isset( $atts['postid'] ) ) {
    		$atts['postid'] = $post->ID;
    	}

    	if ( empty( $atts['postid'] ) ) {
    		return;
    	}

        if ( get_post_meta( $atts['postid'], '_lets_review_onoff', true ) != 1 ) {
    		return;
    	}
    	$frontend = new Lets_Review_Frontend( $this->slug, $this->version, $this->url );
        return $frontend->lets_review_review_box( $atts['postid'] );
    }

    /**
	 * Shortcode list output
	 *
	 * @since 1.2.0
	 * @return Review output
	 */
	public function lets_review_shortcode_list( $atts, $content = '' ) {

		if ( empty( $atts[ 'postid' ] ) && ! isset( $atts[ 'cats' ] ) && ! isset( $atts[ 'tags' ] ) ) {
			return;
		}

		$frontend = new Lets_Review_Frontend( $this->slug, $this->version, $this->url );
		$design =  isset( $atts[ 'design' ] ) ? $atts[ 'design' ] : 'modern';
		$order =  isset( $atts[ 'order' ] ) ? $atts[ 'order' ] : 1;
		$type =  isset( $atts[ 'type' ] ) ? $atts[ 'type' ] : 1;
		$countdown =  isset( $atts[ 'countdown' ] ) ? $atts[ 'countdown' ] : true;
		$proscons =  isset( $atts[ 'proscons' ] ) ? $atts[ 'proscons' ] : 'off';
		$proscons_attr = $proscons == 'on' ? 'cb-pros-cons-on' : 'cb-pros-cons-off';
		switch ( $design ) {
			case 'simple':
				$design = 1;
				$design_attr = 'cb-design-1';
				break;

			default:
				$design = 3;
				$design_attr = 'cb-design-3';
				break;
		}

		$output = '<div class="cb-aff-list lets-review-box-wrap cb-skin-base ' . esc_attr( $design_attr )  . ' clearfix">';

		if ( isset( $atts[ 'title' ] ) ) {
			$output .= '<div class="cb-aff-main-title"><h2>' . $atts[ 'title' ] . '</h2></div>' ;
		}

		$pids = $cats = $tags = $ppp = '';

		if ( ! empty( $atts['source'] ) ) {

			switch ($atts['source']) {
				case 2:
					if ( $atts[ 'cats' ] == 0 ) {
						$atts[ 'cats' ] = '';
					}
					$cats = explode( ',',  $atts[ 'cats' ] );
					$ppp = empty( $atts['ppp'] ) ? 1 : $atts['ppp'];
					$cats = array_filter( $cats ) ? $cats : '';
					break;
				case 3:
					$tags = explode( ',',  $atts[ 'tags' ] );
					$ppp = empty( $atts['ppp'] ) ? 1 : $atts['ppp'];
					break;
				
				default:
					$pids = explode( ',',  $atts[ 'postid' ] );
					$ppp = ! empty( $pids ) ? count($pids) : '';
					break;
			}
		} else {
			if ( empty( $atts[ 'postid' ] ) ) {
				return;
			}
			$pids = explode( ',',  $atts[ 'postid' ] );
			$ppp = ! empty( $pids ) ? count($pids) : '';
		}
		$i = 1;

		$cpts = get_post_types( array( 'public' => true, '_builtin' => false ) );
		$cpts[] = 'post';
		$cpts[] = 'page';

		$meta_key = $type > 2 ? '_lets_review_user_rating' : '_lets_review_final_score_100';

		switch ( $order ) {
			case 2:

				$pids = new WP_Query( array(
					'fields' => 'ids',
					'posts_per_page' => $ppp,
					'post_type'	=> $cpts,
					'post__in' => $pids,
					'category__in' => $cats, 
					'tag__in' => $tags, 
					'ignore_sticky_posts' => true,
					'meta_key' => $meta_key,
	                'orderby' => 'meta_value_num', 
	                'order' => 'DESC', 
					) 
				);
				$pids = $pids->posts;

				break;
			default:
				$pids = new WP_Query( array(
					'fields' => 'ids',
					'meta_key'   => '_lets_review_onoff',
					'meta_value' => 1,
					'post_type'	=> $cpts,
					'posts_per_page' => $ppp,
					'post__in' => $pids,
					'category__in' => $cats, 
					'tag__in' => $tags, 
					'ignore_sticky_posts' => true,
					) 
				);

				$pids = $pids->posts;
				break;
		}

		foreach ( $pids as $pid ) {

			$format = get_post_meta( $pid, '_lets_review_format', true );

			if ( $format > 2 ) {
            	$out_of_5 = ' cb-out-of-5';
            } else {
            	$out_of_5 = '';
            }

			$output .= '<div class="cb-list-entry cb-list-entry-' . intval( $i ) . ' ' . $out_of_5 . ' cb-review-block clearfix">';

			switch ( $design ) {
				case 1:
					$output .= '<a href="' . get_permalink( $pid ) . '">';
					$output .= $countdown == true ? $frontend->lets_review_title( $pid, $i ) : $frontend->lets_review_title( $pid );
					$output .= '</a>';
					$output .= $frontend->lets_review_media_fi( $pid, $design );
					$output .= '<div class="cb-review-text-summary clearfix">';
					$output .= $frontend->lets_review_conclusion( $pid, false );
					$output .= '</div>';

			        $output .= '<div class="cb-review-summary clearfix">';
			        $output .= $frontend->lets_review_final_score( $pid, false, $design );
		            $output .= '</div>';

		            $output .= '<div class="cb-review-aff-summary ' . esc_attr( $proscons_attr ) . '">';
		            if ( $proscons == 'on' ) {
						$output .= '<div class="cb-pros-cons-block clearfix">';
			            $output .= $frontend->lets_review_cons( $pid );
			            $output .= $frontend->lets_review_pros( $pid );
			            $output .= '</div>';
			        }
			        $output .= '<div class="cb-review-block cb-review-pad cb-aff-block cb-clearfix">' . $frontend->lets_review_affiliates( $pid ) . '</div>';
			        $output .= '</div>';

					break;

				default:
				
					$fi = $frontend->lets_review_media_fi( $pid, $design );

					if ( empty( $fi ) ) {
						$fi = get_the_post_thumbnail_url( $pid, array( 1200, 800 ) );
						$fi = '<div class="cb-review-fi lets-review-full-bg" style=" background-image: url( ' . esc_url( $fi ) . ') ; "></div>';
					}

					$output .= $fi;
					$output .= '<div class="cb-review-text-summary clearfix">';
					$output .= '<a href="' . get_permalink( $pid ) . '">';
					$output .= $countdown == true ? $frontend->lets_review_title( $pid, $i ) : $frontend->lets_review_title( $pid );
					$output .= '</a>';
					$output .= $frontend->lets_review_conclusion( $pid, false );
					if ( $proscons == 'on' ) {
						$output .= '<div class="cb-pros-cons-block clearfix">';
			            $output .= $frontend->lets_review_cons( $pid );
			            $output .= $frontend->lets_review_pros( $pid );
			            $output .= '</div>';
			        }
					$output .= '</div>';
			        $output .= '<div class="cb-review-summary clearfix">';
			        $output .= $frontend->lets_review_final_score( $pid, false, $design );
		            $output .= '<div class="cb-review-block cb-review-pad cb-aff-block cb-clearfix">' . $frontend->lets_review_affiliates( $pid ) . '</div>';
		            $output .= '</div>';
					break;
			}

            $output .= '</div>';


            $i++;
		}

    	$output .= '</div>';

    	wp_reset_postdata();

        return $output;
    }

    /**
	 * Shortcode affiliate button
	 *
	 * @since 1.2.0
	 * @return Review output
	 */
	public function lets_review_shortcode_affiliate( $atts, $content = '' ) {

    	if ( empty ( $atts ) ) {
    		return;
    	}

    	$color =  ! empty( $atts[ 'accent' ] ) ? $atts[ 'accent' ] : '#f8d92f';
		$url =  ! empty( $atts[ 'url' ] ) ? $atts[ 'url' ] : '';
		$text =  ! empty( $atts[ 'text' ] ) ? $atts[ 'text' ] : '';
		$border =  ! empty( $atts[ 'border' ] ) ? $atts[ 'border' ] : 'on';
		$alignment =  ! empty( $atts[ 'textalign' ] ) ? $atts[ 'textalign' ] : 'center';
		$rel =  ! empty( $atts[ 'rel' ] ) ? $atts[ 'rel' ] : 'nofollow';
		$animation =  ! empty( $atts[ 'animation' ] ) ? $atts[ 'animation' ] : 1;
		$target =  ! empty( $atts[ 'target' ] ) && $atts[ 'target'] == 'samewindow' ? '_self' : '_blank';
		$size =  ! empty( $atts[ 'size' ] ) && $atts['size'] == 'big' ? 'lr-button-big' : 'lr-button-small';

		switch ( $border ) {
			case 'on':
				$border = 'cb-border-on';
				break;

			default:
				$border = 'cb-border-off';
				break;
		}

		switch ( $alignment ) {
			case 'center':
				$alignment = 'cb-aff-ta-center';
				break;

			default:
				$alignment = 'cb-aff-ta-left';
				break;
		}

		$output = '<div class="cb-aff-standalone-button cb-skin-base cb-design-2 ' . esc_attr( $border ) . ' ' . esc_attr( $alignment ) . '">';

		if ( isset( $atts[ 'maintitle' ] ) ) {
			$output .= '<div class="cb-aff-title cb-block-header">' . $atts[ 'maintitle' ] . '</diV>';
		}
		$icon_class_1 = apply_filters( 'lets_review_aff_icon_1_class', '' );
		$shopping_cart = get_option( 'lets_review_gen_type_shopping_onoff' ) == 1 ? '<div class="custom-shopping-icon cb-button-ani-1">' . get_option( 'lets_review_gen_type_shopping_icon' ) . '</div>'  : '<i class="' . esc_attr( $icon_class_1 ) . 'fa fa-shopping-cart cb-button-ani-' . intval( $animation ) . '"></i>';


        $output .= '<div class="cb-aff-block"><div class="cb-aff-button"><a href="' . esc_url( $url ) . '" rel="' . esc_attr( $rel ) . '" target="' . esc_attr( $target ) . '" class="' . esc_attr( $size ) . '">' . $text . '<span class="cb-icon-wrap" style="background-color: ' . esc_attr( $color ) . ';">' . $shopping_cart . '<i class="fa fa-long-arrow-right cb-button-ani-' . intval( $animation ) . '-hid cb-button-ani-' . intval( $animation ) . '"></i></span></a></div></div>';

        $output .= '</div>';

        return $output;

    }

    /**
	 * Shortcode user rating
	 *
	 * @since 2.0.0
	 * @return Review output
	 */
	public function lets_review_shortcode_user_rating( $atts, $content = '' ) {

    	if ( empty ( $atts['postid'] ) || empty( $atts['id'] ) ) {
    		return esc_html__( 'Missing attributes. Please use the Shortcode tool to insert Let\'s Review shortcodes.', 'lets-review' );
    	}

    	$atts['content'] = empty( $content ) ? '' : $content;

		$frontend = new Lets_Review_Frontend( $this->slug, $this->version, $this->url );
		return $frontend->lets_review_user_rating_box( $atts );

    }

    /**
	 * Shortcode unique button
	 *
	 * @since 2.0.0
	 * @return Review output
	 */
	public function lets_review_shortcode_unique( $atts, $content = '' ) {

    	if ( empty ( $atts ) ) {
    		return;
    	}
    	$atts['conclusion'] = empty( $content ) ? '' : $content;

    	$frontend = new Lets_Review_Frontend( $this->slug, $this->version, $this->url );
        return $frontend->lets_review_review_box( '', $atts );

    }

}