<?php
/**
 *
 * Let's Review Visitors Class
 *
 * @since      2.0.0
 *
 * @package    Let's Review
 * @subpackage lets-review/frontend
 */

class Lets_Review_Visitors {

	/**
	 * Var for Let's Review slug.
	 *
	 * @since    2.0.0
	 */
	private $slug;

	/**
	 * Var for Let's Review version.
	 *
	 * @since    2.0.0
	 */
	private $version;

	/**
	 * Var for Let's Review URL.
	 *
	 * @since    2.0.0
	 */
	private $url;

	/**
     * Frontend Constructor
     *
     * @since 2.0.0
     *
    */
	public function __construct( $slug = NULL, $version = NULL, $url = NULL ) {

		$this->slug = $slug;
		$this->version = $version;
		$this->url = $url;
		

	}

	/**
	 * Output
	 *
	 * @since 2.0.0
	 */
	public function lets_review_output( $comment_text = '', $comment = '') {

		$pid = $comment->comment_post_ID;

		if ( get_post_meta( $pid, '_lets_review_onoff', true ) != 1 || is_admin() ) {
			return $comment_text;
		}
		
		$cid = $comment->comment_ID;
		
		$data['f_score'] = get_comment_meta( $cid, 'lets_review_ur_f_score', true );
		$data['criterias'] = get_comment_meta( $cid, 'lets_review_ur_criterias', true );
		$data['headline'] = get_comment_meta( $cid, 'lets_review_ur_headline', true );
		$data['format'] = get_comment_meta( $cid, 'lets_review_ur_format', true );

		if ( ! array_filter( $data ) ) {
			return $comment_text;
		}

		$frontend = new Lets_Review_Frontend( $this->slug, $this->version, $this->url );
		$color = $frontend->lets_review_color( $pid );
		$format = get_post_meta( $pid, '_lets_review_format', true );
        $out_of_5 = $format > 2 ? '5' : '-';
        $design_skin = get_post_meta( $pid, '_lets_review_design_skin', true ) ? get_post_meta( $pid, '_lets_review_design_skin', true ) : 1;

		$crits = '<div class="cb-skin-base cb-lr-font-heading cb-font-header lets-review-ur-wrap cb-design-min cb-clearfix cb-skin-version-' . $design_skin . ' cb-score-type-' . $format . ' cb-out-of-' . $out_of_5 . '">';


		if ( ! empty( $data['criterias'] ) ) {

			$crits .= '<div class="lets-review-breakdown">' . esc_html__( 'Breakdown', 'lets-review' ) . '</div>';	
			$crits .= '<div class="cb-review-block">';

			switch ( $data['format'] ) {
				case 2:
					if ( $format == 1 ) {
						$data['f_score'] = intval( $data['f_score'] * 10 );
						foreach ( $data['criterias'] as $key => $value ) {
							$data['criterias'][$key]['score'] = intval( $value['score'] * 10 );
						}
					} elseif ( $format > 2 ) {
						$data['f_score'] = number_format( ( $data['f_score'] / 2 ), 1 ) + 0;
						foreach ( $data['criterias'] as $key => $value ) {
							$data['criterias'][$key]['score'] = floatval( $value['score'] / 2 );
						}
					}
					break;
				case 1:
					if ( $format == 2 ) {
						$data['f_score'] = number_format( ( $data['f_score'] / 10 ), 1 ) + 0;
						foreach ( $data['criterias'] as $key => $value ) {
							$data['criterias'][$key]['score'] = intval( $value['score'] / 10 );
						}
					} elseif ( $format > 2 ) {
						$data['f_score'] = number_format( ( $data['f_score'] / 20 ), 1 ) + 0;
						foreach ( $data['criterias'] as $key => $value ) {
							$data['criterias'][$key]['score'] = floatval( $value['score'] / 20 );
						}
					}
					break;
				
				default:
					if ( $format == 1 ) {
						$data['f_score'] = intval( $data['f_score'] * 20 );
						foreach ( $data['criterias'] as $key => $value ) {
							$data['criterias'][$key]['score'] = intval( $value['score'] * 20 );
						}
					} elseif ( $format == 2 ) {
						$data['f_score'] = number_format( ( $data['f_score'] * 2 ), 1 ) + 0;
						foreach ( $data['criterias'] as $key => $value ) {
							$data['criterias'][$key]['score'] = number_format( ( $value['score'] * 2 ), 1 ) + 0;
						}
					}
					break;
			}


			$args = array();
			$args['user_review_crits'] = $data['criterias'];
			$args['format'] = $format;
            $args['animation'] = 3;
            $args['accent'] = $color;
			$crits .= $frontend->lets_review_criterias( '', $args );

			$crits .= '</div>';
	    	$crits .= '</div>';

	    }
	    
	    if ( ! empty( $data['f_score'] ) ) {
	    	$f_score_output = '<div class="lets-review-ur-f-wrap cb-lr-font-heading cb-font-header cb-score-type-' . $format . '" style="background: ' . esc_attr( $color ) . ' ;">';
			$f_score_output .= '<div class="lets-review-ur-value cb-final-score" >' . $data['f_score'] . '</div>';
			$f_score_output .= '</div>';
	    }
	    
	    $headline = '<div class="lets-review-ur-headline cb-lr-font-heading cb-font-header">' . $data['headline'] . '</div>';
		return $f_score_output . $headline . $comment_text . $crits;

	}

	/**
	 * Save
	 *
	 * @since 2.0.0
	 */
	public function lets_review_insert( $id, $comment ) {

		$f_score = empty( $_POST['lets_review_final_score'] ) ? '' : $_POST['lets_review_final_score'];

		if ( empty( $f_score ) ) {
			return;
		}

		if ( ! empty( $_POST['lets_review_ur_criterias'] ) ) {
			$i = 1;
			$sanitized_array = array();
			foreach ( $_POST['lets_review_ur_criterias'] as $key => $value ) {
	            $sanitized_array[ $i ] = array( 'title' => wp_kses_data( $key ), 'score' => floatval( $value ) ); 
	            $i++;
	        }

	        add_comment_meta( $id, 'lets_review_ur_criterias', $sanitized_array );
		}

		if ( ! empty( $_POST['lets_review_ur_headline'] ) ) {
			add_comment_meta( $id, 'lets_review_ur_headline', wp_kses_data( $_POST['lets_review_ur_headline'] ) );
		}
		
		add_comment_meta( $id, 'lets_review_ur_format', intval( $_POST['lets_review_ur_format'] ) );
		add_comment_meta( $id, 'lets_review_ur_f_score', floatval( $f_score ) );

	}

   	/**
	 * Comment Form
	 *
	 * @since 2.0.0
	 */
	public function lets_review_form() {

		global $post;
		$pid = $post->ID;
		if ( get_post_meta( $pid, '_lets_review_onoff', true ) != 1 ) {
    		return;
    	}
		$options = get_post_meta( $pid, '_lets_review_criterias', true );
		$format = get_post_meta( $pid, '_lets_review_format', true );
        $design = get_post_meta( $pid, '_lets_review_design', true );
        $color = get_post_meta( $pid, '_lets_review_color', true );
        $design_skin = get_post_meta( $pid, '_lets_review_design_skin', true ) ? get_post_meta( $pid, '_lets_review_design_skin', true ) : 1;
        $max = 5;
        $step = 0.1;
        if ( $format == 1 ) { 
        	$max = 100; 
        	$step = 1; 
        } elseif ( $format == 2 ) { 
        	$max = 10; 
        }
        $user_default_onoff = get_option( 'lets_review_gen_user_review_onoff_default', 1 );

		?>
		
		<p class="lets-review-form-onoff cb-clearfix">
			<label><?php esc_html_e( 'Is this a review?', 'lets-review' ); ?></label> 
			<label class="lets-review-ur-onoff-label cb-clearfix">
			    <input type="radio" name="lets_review_ur_onoff" value="off" <?php if ( $user_default_onoff != 2 ) { ?>checked="checked"<?php }?> class="lets-review-ur-onoff" />
			    <span class="lets-review-no" for="lets_review_ur_onoff"><?php esc_html_e( 'No', 'lets-review' ); ?></span>
			  </label>
			  <label class="lets-review-ur-onoff-label cb-clearfix">
			    <input type="radio" name="lets_review_ur_onoff" value="on" <?php if ( $user_default_onoff == 2 ) { ?>checked="checked"<?php }?> class="lets-review-ur-onoff" />
			   <span class="lets-review-yes" for="lets_review_ur_onoff"><?php esc_html_e( 'Yes', 'lets-review' ); ?></span>
			  </label>
			  
		</p>

		<p class="lets-review-form<?php if ( $user_default_onoff == 2 ) { ?> lets-review-form-show<?php } ?>"><label for="lets_review_ur_headline"><?php esc_html_e( 'Review Headline', 'lets-review' ); ?></label> <input name="lets_review_ur_headline" type="text" value="" size="30" aria-required="true"></p>

		<input name="lets_review_ur_format" type="hidden" value="<?php echo intval( $format ); ?>">
		<div class="lets-review-form lets-review-form-crits cb-clearfix cb-skin-base cb-lr-font-p cb-lr-font-p cb-design-3 cb-skin-version-<?php echo esc_attr( $design_skin ) ; ?> cb-clearfix" data-max="<?php echo intval( $max ); ?>" data-step="<?php echo floatval( $step ); ?>">
		<?php if ( ! empty ( $options ) ) { ?>			
			<div class="lets-review-all-crits cb-clearfix">
				<?php $i = 1; ?>
				<?php foreach ( $options as $key ) { ?>
	                <div class="cb-bar">
	                	<span class="cb-criteria-title"><?php echo esc_attr( $key['title'] ); ?></span>
	                <div class="cb-criteria-score cb-clearfix">
	                    <div class="cb-review-slider lets-review-c-slider" data-color="<?php echo esc_attr( $color ) ; ?>"></div>
	                    <input type="text" value="0" name="lets_review_ur_criterias[<?php echo esc_attr( $key['title'] ); ?>]" class="cb-cri-score lets-review-ind-crit cb-input" data-format="<?php echo intval( $format ); ?>" readonly>
	                </div>
	            	<?php $i++; ?>
	            	</div>
	            <?php } ?>
	        </div> <!-- .lets-review-all-crits -->
		<?php } ?>
        	<div class="cb-bar cb-final-score-wrap">
                <div class="cb-criteria-title">
                    <span class="cb-list-title"><?php esc_html_e( 'Final Score', 'lets-review' ); ?></span>
                </div>
                <div class="cb-criteria-score cb-clearfix">
                    <div class="cb-review-slider lets-review-c-slider" data-color="<?php echo esc_attr( $color ) ; ?>"></div>
                    <input type="text" value="0" name="lets_review_final_score" class="lets-review-final-score cb-cri-score cb-input" readonly>
                    <input type="hidden" value="0" name="lets_review_final_score_100" class="lets-review-100" readonly>
           		</div>
        	</div>
        </div>
	<?php
	}

}