/**
 * Copyright: Codetipi
 * Plugin: Let's Review
 * Version: 2.6.3
 */
 (function( $ ) {

    'use strict';
	var letsReviewScripts = {
		init: function() {
			this.cacheDom();
			this.cacheData();
			if ( parseInt( letsReview.letsReviewUReviews ) === 1 ) {
				this.sliderLoaders();
			}
			this.bindEvents();
			this.lightboxInit();
			this.tooltipInit();
			this.tempAni();
		},
		cacheDom: function() {
			this.$doc				= $( document );
			this.$win 				= $( window );
			this.$body				= $( 'body' );
			this.$tooltip			= $( '.lets-review-tip-f' );
			this.$lightbox 			= $( '.lets-review-lightbox' );
			this.rtl 				= this.$body.hasClass('rtl') ? true : false;
			this.$userRating 		= $( '[id^="cb-user-rating-"]' );
			this.$formLabels		= $( '.lets-review-ur-onoff-label' );
			this.$lrForm			= $( '.lets-review-form' );
			if ( parseInt( letsReview.letsReviewUReviews ) === 1 ) {
				this.dataGather 	= $(".lets-review-form-crits:first").data();
				this.$cSliders 		= $( '.lets-review-c-slider' );
			}

		},
		cacheData: function() {
			this.$winWidth			= this.$win.width();
		},
		bindEvents: function() {
			if ( this.$body.hasClass( 'lr-binded' ) ) {
				return;
			}
			this.$body.addClass('lr-binded');
			this.$win.on( 'resize', this.resize.bind(this) );
			this.$body.on( 'click', this.$formLabels, this.formLabels );
			this.$body.on( 'click touchend','#swipebox-slider .current img', function(){
				return false;
			}).on('click touchend','#swipebox-slider .current', function(){
				$('#swipebox-close').trigger('click' );
			});
			this.$doc.on( 'slide', '.lets-review-c-slider', this.slideIt );
		},
		formLabels: function() {
			if ( letsReviewScripts.$formLabels.length === 0 ) {
				return;
			}
			if ( $(this).find('input[name=lets_review_ur_onoff]:checked').val() === 'on' ) {
				letsReviewScripts.$lrForm.slideDown( 200 );
 			} else {
 				letsReviewScripts.$lrForm.slideUp( 200 );
 			}
		},
		lightboxInit: function() {
			if ( this.$body.hasClass( 'lr-binded' ) ) {
				return;
			}
			if ( !!$.prototype.swipebox ) {
				this.$lightbox.swipebox( {
					hideBarsDelay : 0
				} );
			}
		},
		tooltipInit: function() {
			if ( this.$winWidth < 767 ) return;

            this.$tooltip.tipper({
		        direction: 'bottom',
		        follow: true
		    });

		},
		resize: function( el, value ) {
			this.cacheData();
			this.tooltipInit();
		},
		triggers: function( el, value ) {
			$.each( this.$boxWrap.find('.cb-overlay span'), function( i, element ) {
				element = $( element );
		        if ( element.visible(true) ) {
		            element.removeClass('cb-trigger-zero' );
		            if ( element.closest('.lets-review-box-wrap').data('format') > 2 ) {
		            	element.addClass('cb-5-trigger' );
		            } else {
		            	element.addClass('cb-trigger' );
		            }
		        }
		    });
		},
		tempAni: function( e ) {
			var ani = document.querySelectorAll( '.lets-review-box-wrap .cb-overlay span' ),
				observer = new IntersectionObserver(function (entries) {
				entries.forEach(function (entry) {
					if ( entry.intersectionRatio > 0 ) {
						entry.target.classList.remove('cb-trigger-zero' );
						var $elem = $( entry.target )
						if ( $elem.closest('.lets-review-box-wrap').data('format') > 2 ) {
			            	$elem.addClass('cb-5-trigger' );
			            } else {
			            	$elem.addClass('cb-trigger' );
			            }
			            observer.unobserve(entry.target);

					}
				});
			}, { threshold: [0] });
			for ( var i = ani.length - 1; i >= 0; i-- ) {
				observer.observe( ani[i] );
			}
		},
		slideIt: function( event, ui) {
			var eachSlider = $(this );
			eachSlider.next().val( ui.value );
			if ( eachSlider.next().hasClass('lets-review-ind-crit') ) {
				letsReviewScripts.scoreCalc( eachSlider.next() );
			}
		},
		sliderLoaders: function() {
			if ( this.$body.hasClass( 'lr-binded' ) ) {
				return;
			}
			this.$cSliders.each( function() {
				var currentSlider = $(this);
				currentSlider.slider({
					min: 0,
					max: letsReviewScripts.dataGather['max'],
					range: 'min',
					step: letsReviewScripts.dataGather['step'],
					start: function( event, ui ) {
						currentSlider.find('.ui-slider-range').css( 'background-color', currentSlider.data('color') );
					}
				});
			});
		},
		scoreCalc: function( sliderTarget ) {

	        var cbTempTotal = 0;
	        var cbTotal;
	        var cbSliderFormat = sliderTarget.data('format' );
	        var cbCritScores = sliderTarget.closest('.lets-review-form-crits').find('.lets-review-all-crits .cb-cri-score' );
	        var cbFinalScoreInput = sliderTarget.closest('.lets-review-form-crits').find('.lets-review-final-score' );
	        var cbFinalScoreInput100 = sliderTarget.closest('.lets-review-form-crits').find('.lets-review-100' );

	        cbCritScores.each(function() {
	            cbTempTotal += parseFloat( $(this).val() );
	        });

	        if ( cbTempTotal === 0 && cbFinalScoreInput.val() > 0 ) {
	        	return;
	        }

	        if ( parseInt( cbSliderFormat ) === 1 ) {
	        	cbTotal = Math.round( cbTempTotal / cbCritScores.length );
	        } else {

	        	if ( letsReview.doubleDecimalStars === 'on' ) {
	        		cbTotal = ( cbTempTotal / cbCritScores.length ).toFixed(2);
	        	} else {
	        		cbTotal = Math.round( cbTempTotal / cbCritScores.length * 10 ) / 10;
	        	}

	        }

	        if ( isNaN(cbTotal) ) {
	        	cbFinalScoreInput.val('' );
	        	cbFinalScoreInput.prev().slider( 'option', { 
	        		max: letsReviewScripts.dataGather['max'], 
	        		step: letsReviewScripts.dataGather['step'], 
	        		value: cbFinalScoreInput.val() 
	        	});
	    	} else {
				cbFinalScoreInput.val(cbTotal);
	    		cbFinalScoreInput.prev().slider( 'option', { 
	    			max: letsReviewScripts.dataGather['max'], 
	    			step: letsReviewScripts.dataGather['step'], 
	    			value: cbTotal
	    		});

		    }

	    	if ( parseInt( cbSliderFormat ) === 1 ) {
				cbFinalScoreInput100.val( cbFinalScoreInput.val() );
			} else if ( parseInt( cbSliderFormat ) === 2 ) {
				cbFinalScoreInput100.val( cbFinalScoreInput.val() * 10 );
			} else {
				cbFinalScoreInput100.val( cbFinalScoreInput.val() * 20 );
			}

		},

	};

	letsReviewScripts.init();

	var cbBodyRTL = false,
		cbUserRating = $('[id^="cb-user-rating-"]'),
		cbUSerRatingCookie = Cookies.get('lets_review_user_rating'),
		cbUserRatingTitle, cbUserRatingScore, cbUserRatingScoreCache, cbUserRatingWidth, cbBaseX, cbUserRatingLocation, cbOverlaySpan, cbUserRatingLocationOffset, cbUserRatingWidthCache, cbUserRatingTitleCache, cbUserRatingPId, cbUserRatingUId, cbThis, letsReviewWrap, cbHover, cbType, cbTypeFS, cbOverlaySpanCalc, cbOutOf5;


    if ( cbUserRating.length ) {

    	cbUserRating.each(function() {
    		cbThis = $(this);
    		if ( cbThis.hasClass('lr-running') ) {
    			return true;
    		}
    		letsReviewWrap = cbThis.closest('.lets-review-box-wrap' );
			cbUserRatingPId = letsReviewWrap.data('pid' );
			cbUserRatingUId = letsReviewWrap.data('uid' );

			if ( cbThis.hasClass( 'cb-rated' ) || ( cbUSerRatingCookie instanceof Array && ( cbUSerRatingCookie.indexOf( cbUserRatingPId ) > -1 || cbUSerRatingCookie.indexOf( cbUserRatingUId ) > -1 ) ) ) {
				return;
			}

			cbThis.addClass('lr-running');

			switch( letsReviewWrap.data('format') ) {
			    case 1:
			        cbHover = cbThis.find('.cb-bar' );
			        break;
			    case 2:
			        cbHover = cbThis.find('.cb-bar' );
			        break;
			    default:
			        cbHover = cbThis.find('.cb-overlay' );
			}

			cbHover.on('mousemove click mouseleave mouseenter', function(e) {
				cbThis = $(this).closest('[id^="cb-user-rating-"]' );

				letsReviewWrap = cbThis.closest('.lets-review-box-wrap' );

				if ( e.type === 'mouseenter' ) {
					cbUserRatingTitle = cbThis.find('.cb-criteria' );
					cbUserRatingTitleCache = cbUserRatingTitle.html();
					cbUserRatingScore = cbThis.find('.cb-criteria-score' );
					cbUserRatingScoreCache = cbUserRatingScore.data('cb-score-cache' );
					cbUserRatingWidthCache = cbUserRatingScore.data('cb-width-cache' );
					cbUserRatingLocation = cbThis.find('.cb-overlay' );
					cbUserRatingLocationOffset = cbUserRatingLocation.offset();
					cbUserRatingWidth = cbUserRatingLocation.find('> span' );
		            cbUserRatingTitle.html( cbUserRatingTitle.data('cb-txt') );
		        }

				cbBaseX = Math.ceil( ( e.pageX - cbUserRatingLocationOffset.left ) / ( cbUserRatingLocation.width() / 100 ) );
				cbOverlaySpan = cbBodyRTL === true ? 100 - cbBaseX : cbBaseX;

	            if ( cbOverlaySpan > 100 ) { cbOverlaySpan = 100; }
        		if ( cbOverlaySpan < 1 ) { cbOverlaySpan = 0; }

        		switch( letsReviewWrap.data('format') ) {
				    case 1:
				        cbOverlaySpanCalc = cbOverlaySpan;
				        cbOutOf5 = false;
				        break;
				    case 2:
				        cbOverlaySpanCalc = Math.round( cbOverlaySpan * 10 ) / 100;
				        cbOutOf5 = false;
				        break;
				    default:
				        cbOverlaySpanCalc = Math.round( ( cbOverlaySpan / 20 ) * 10 ) / 10;
				        cbOutOf5 = true;
				}

				if ( letsReviewWrap.hasClass('cb-out-of-5') ) {
					cbUserRatingWidth.stop().animate( { 'width' : (100 - cbOverlaySpan) + '%'}, 15);
				} else {
					cbUserRatingWidth.stop().animate( { 'width' : cbOverlaySpan + '%'}, 15);
				}

        		cbUserRatingScore.html( cbOverlaySpanCalc );

        		if ( ( e.type === 'mouseleave' ) || ( e.type === 'click' ) ) {

        			if ( letsReviewWrap.hasClass('cb-out-of-5') ) {
						cbUserRatingWidth.stop().animate( { 'width' : (100 - cbUserRatingWidthCache) + '%' }, 200);
					} else {
						cbUserRatingWidth.stop().animate( { 'width' : cbUserRatingWidthCache + '%' }, 200);
					}

        			cbUserRatingScore.html( cbUserRatingScoreCache );
        			cbUserRatingTitle.html (cbUserRatingTitleCache );
        		}

        		if ( e.type === 'click' ) {
		            $(this).off('mousemove click mouseleave mouseenter' );
		            cbThis.addClass('cb-rated cb-lr-tip-f' );

		            $.ajax({
		                type : "POST",
		                data : { action: 'lets_review_a_cb', letsReviewNonce: letsReview.letsReviewNonce, letsReviewScore: cbOverlaySpan, letsReviewPostID: letsReviewWrap.data('pid'), letsReviewFormat: letsReviewWrap.data('format'), letsReviewUID: letsReviewWrap.data('uid') },
		                url  : letsReview.letsReviewAUrl,
		                dataType:"json",
		                beforeSend: function() {
		                	cbType = letsReviewWrap.data('type' );
							cbTypeFS = letsReviewWrap.find('.cb-score-box' );
		                	cbThis.addClass('cb-voting' );

		                	if ( cbType === 3 && cbOutOf5 === false ) {
		                		cbTypeFS.addClass('cb-fs-voting' );
		                	}
						},
		                success : function( data ){

		                	cbUserRatingLocation.find('> span').css('width', ( data[0] + '%' ) );
		                	cbThis.find('.cb-votes-count').html( data[2] );
		                	cbUserRatingScore.html( data[1] );
		                    Cookies.set('lets_review_user_rating', data[3], { expires: 7 });
		                    cbThis.removeClass('cb-voting' );
		                    if ( cbType === 3  && cbOutOf5 === false ) {
		                    	cbTypeFS.find('.cb-final-score').html( data[1] );
		                    	cbTypeFS.removeClass('cb-fs-voting cb-score--' );
		                    }
		                    cbThis.tipper({
						        direction: 'bottom',
						        follow: true
						    });
		                },
		                error : function(jqXHR, textStatus, errorThrown) {
		                    console.log("cbur " + jqXHR + " :: " + textStatus + " :: " + errorThrown);
		                }
		            });

		            return false;
        		}

			});

    	});

    }
	
})( jQuery );